@@ -70,8 +70,8 @@ static void usage()
 
 static void version()
 {
-    printf("saphire version %s.", getenv("SAPHIRE_VERSION"));
-    printf("author Daisuke Minato.\n");
+    printf("saphire version %s.\n", getenv("SAPHIRE_VERSION"));
+    printf("author Daisuke Minato(ab25cq@gmail.com).\n");
     
     exit(0);
 }
