@@ -8,12 +8,11 @@ extern volatile BOOL gSigUser;
 
 /// ޥɤбʸ
 enum eCommandKind { 
-    kObject,
-    kPointer,
-    kVar, kGlobal, kExport, 
+    kObject, kPointer, kVar, kGlobal, kExport, 
     kAry, kAryAdd, kAryErase, 
     kHash, kHashAdd, kHashErase,  
-    kDef, kInherit, kClass,
+    kDef, kInherit, kSelf, kClass,
+    kSweep, kShow,
     kSubshell, kMSleep, kTrue, kFalse, kTest,
     kIndex, kRIndex, kLength, kLc, kUc,
     kChomp, kSubstr, kEval, kFg, kBg, 
@@ -50,8 +49,6 @@ enum eCommandKind {
     kMMove ,
     kMMoveImmediately,
     kMPrintw, 
-    kSweep,
-    kShow,
     kYeild,
     kEach,
     kForeach,
@@ -363,6 +360,7 @@ typedef struct _sFunction {
     string_obj* arg_name;
     //vector_obj* args;       // ե󥹤ΰ
     sStatments* statments; // ̿ɽ
+    BOOL input;             // ¹Իξ
 
     struct _sFunction* parent;     // С饤ɤȤο
 } sFunction;
@@ -375,18 +373,6 @@ void sFunction_save(sFunction* self, int fd);
 sFunction* sFunction_load(int fd);
 void sFunction_view(sFunction* self);
 
-typedef struct _sClass {
-    string_obj* name;      // 饹̾
-    sStatments* statments; // ̿ɽ
-    struct _sClass* parent;        // С饤
-} sClass;
-
-sClass* sClass_new(char* name, sStatments* statments, sClass* parent);
-sClass* sClass_new2(sClass* klass);
-  
-void sClass_save(sClass* self, int fd);
-sClass* sClass_load(int fd);
-void sClass_view(sClass* self);
 
 typedef struct {
     string_obj* mName;
