@@ -39,7 +39,8 @@ char* gStatmentKindStrs[kCommand+1] = {
     "object", "pointer", "var", "global", "export", 
     "ary", "ary_add", "ary_erase", 
     "hash", "hash_add", "hash_erase",
-    "def", "inherit", "class",
+    "def", "inherit", "self", "class",
+    "sweep", "show",
     "subshell", "msleep", "true",  "false", "[",  
     "index", 
     "rindex", 
@@ -82,8 +83,6 @@ char* gStatmentKindStrs[kCommand+1] = {
     "mmove",
     "mmove_immediately",
     "mprintw",
-    "sweep",
-    "show",
     "yeild",
     "each",
     "foreach",
@@ -190,11 +189,12 @@ BOOL gSaphireBackground;
 hash_obj* gObjects;
     // オブジェクト キーはオブジェクト名 内容はsObject*
 
-sObject* sObject_new(char* name, sObject* parent) 
+sObject* sObject_new(char* name, sClass* klass, sObject* parent) 
 {
     sObject* self = MALLOC(sizeof(sObject));
 
     self->mName = STRING_NEW(name);
+    self->mClass = klass;
     self->mGlobals = HASH_NEW(15);
     self->mHashs = HASH_NEW(15);
     self->mArrays = HASH_NEW(15);
@@ -1422,14 +1422,6 @@ sCommand* sCommand_new2(sCommand* command)
         self->mExtra = sSubshell_new2(command->mExtra);
         break;
 
-    case kDef:
-        self->mExtra = sFunction_new2(command->mExtra);
-        break;
-
-    case kClass:
-        self->mExtra = sClass_new2(command->mExtra);
-        break;
-
     default:
         self->mExtra = NULL;
         break;
@@ -1471,14 +1463,6 @@ void sCommand_view(sCommand* self)
     case kSubshell:
         sSubshell_view(self->mExtra);
         break;
-
-    case kDef:
-        sFunction_view(self->mExtra);
-        break;
-
-    case kClass:
-        sClass_view(self->mExtra);
-        break;
     }
 }
 
@@ -1535,14 +1519,6 @@ void sCommand_save(sCommand* self, int fd)
     case kSubshell:
         sSubshell_save(self->mExtra, fd);
         break;
-        
-    case kDef:
-        sFunction_save(self->mExtra, fd);
-        break;
-        
-    case kClass:
-        sClass_save(self->mExtra, fd);
-        break;
     }
 }
 
@@ -1601,14 +1577,6 @@ sCommand* sCommand_load(int fd)
         self->mExtra = sSubshell_load(fd);
         break;
         
-    case kDef:
-        self->mExtra = sFunction_load(fd);
-        break;
-        
-    case kClass:
-        self->mExtra = sClass_load(fd);
-        break;
-        
     default:
         self->mExtra = NULL;
     }
@@ -1945,6 +1913,7 @@ sStatments* sStatments_new()
     sStatments* self = MALLOC(sizeof(sStatments));
 
     self->mStatments = VECTOR_NEW(30);
+    self->mSource = STRING_NEW("");
 
     return self;
 }
@@ -1961,6 +1930,8 @@ sStatments* sStatments_new2(sStatments* statments)
         vector_add(self->mStatments, sStatment_new2(vector_item(statments->mStatments, i)));
     }
 
+    self->mSource = STRING_NEW(string_c_str(statments->mSource));
+
     return self;
 }
 void sStatments_view(sStatments* self)
@@ -1986,6 +1957,16 @@ void sStatments_save(sStatments* self, int fd)
     for(i=0; i<vector_size(self->mStatments); i++) {
         sStatment_save(vector_item(self->mStatments, i), fd);
     }
+
+    n = string_length(self->mSource);
+    if(write(fd, &n, sizeof(int)) < 0) {
+        perror("write");
+        exit(1);
+    }
+    if(write(fd, string_c_str(self->mSource), sizeof(char)*n) < 0) {
+        perror("write");
+        exit(1);
+    }
 }
 
 sStatments* sStatments_load(int fd)
@@ -2005,6 +1986,20 @@ sStatments* sStatments_load(int fd)
         vector_add(self->mStatments, sStatment_load(fd));
     }
     
+    if(read(fd, &n, sizeof(int)) < 0) {
+        perror("read");
+        exit(1);
+    }
+
+    char* buf = MALLOC(sizeof(char)*(n+1));
+    if(read(fd, buf, sizeof(char)*n) < 0) {
+        perror("read");
+        exit(1);
+    }
+    buf[n] = 0;
+
+    self->mSource = STRING_NEW(buf);
+    
     return self;
 }
 
@@ -2017,6 +2012,7 @@ sClass* sClass_new(char* name, sStatments* statments, sClass* parent)
     self->name = STRING_NEW(name);
     self->statments = statments;
     self->parent = parent;
+    self->input = FALSE;
 
     return self;
 }
@@ -2040,6 +2036,8 @@ sClass* sClass_new2(sClass* klass)
         self->parent = NULL;
     }
 
+    self->input = FALSE;
+
     return self;
 }
 
@@ -2104,6 +2102,7 @@ sClass* sClass_load(int fd)
     if(c) { 
         self->parent = sClass_load(fd);
     }
+    self->input = FALSE;
 
     return self;
 }
@@ -2116,21 +2115,21 @@ void sClass_view(sClass* self)
 /////////////////////////////////////////////////////////
 // 関数
 /////////////////////////////////////////////////////////
-sFunction* sFunction_new(char* name, MANAGED sStatments* statments, char* arg_name, sFunction* parent)
+sFunction* sFunction_new(char* name, sStatments* statments, char* arg_name, sFunction* parent)
 {
     sFunction* self = MALLOC(sizeof(sFunction));
+
     self->name = STRING_NEW(name);
-    self->arg_name = STRING_NEW(arg_name);
-    self->parent = parent;
-/*
-    self->args = VECTOR_NEW(10);
-    int i;
-    for(i=0; i<vector_size(args); i++) {
-        vector_add(self->args, STRING_NEW(string_c_str(vector_item(args, i))));
+    if(arg_name) {
+        self->arg_name = STRING_NEW(arg_name);
     }
-*/
+    else {
+        self->arg_name = STRING_NEW("");
+    }
+    self->parent = parent;
     
     self->statments = statments;
+    self->input = FALSE;
 
     return self;
 }
@@ -2139,14 +2138,13 @@ sFunction* sFunction_new2(sFunction* func)
 {
     sFunction* self = MALLOC(sizeof(sFunction));
     self->name = STRING_NEW(string_c_str(func->name));
-    self->arg_name = STRING_NEW(string_c_str(func->arg_name));
-/*
-    self->args = VECTOR_NEW(10);
-    int i;
-    for(i=0; i<vector_size(func->args); i++) {
-        vector_add(self->args, STRING_NEW(string_c_str(vector_item(func->args, i))));
+    if(func->arg_name) {
+        self->arg_name = STRING_NEW(string_c_str(func->arg_name));
     }
-*/
+    else {
+        self->arg_name = STRING_NEW("");
+    }
+
     if(self->parent) {
         self->parent = sFunction_new2(func->parent);
     }
@@ -2160,6 +2158,7 @@ sFunction* sFunction_new2(sFunction* func)
     else {
         self->statments = NULL;
     }
+    self->input = FALSE;
 
     return self;
 }
@@ -2289,6 +2288,7 @@ sFunction* sFunction_load(int fd)
         vector_add(self->args, STRING_NEW(buf));
     }
 */
+    self->input = FALSE;
 
     return self;
 }
@@ -2625,7 +2625,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.3.2", 1);
+    setenv("SAPHIRE_VERSION", "3.3.4", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
