@@ -894,203 +894,6 @@ static BOOL read_command_parse_while_statment(char** p, sCommand* command, sStat
     return TRUE;
 }
 
-/// def文読み込み
-static BOOL read_command_parse_def_statment(char** p, sCommand* command, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, char* sname, int* sline)
-{
-    skip_spaces(p, not_evaled);
-
-    /// 関数名を得る ///
-    string_obj* name = STRING_NEW("");
-    while(**p >= 'a' && **p <= 'z' 
-            || **p >= 'A' && **p <= 'Z'
-            || **p == '_' 
-            || **p >= '0' && **p <= '9')
-    {
-        string_push_back2(not_evaled, **p);
-        string_push_back2(name, **p);
-        (*p)++;
-    }
-
-    /// 引数名指定 ///
-    string_obj* arg_name = STRING_NEW("");
-    if(**p == '(') {
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-
-        skip_spaces(p, not_evaled);
-
-        while(**p >= 'a' && **p <= 'z' 
-            || **p >= 'A' && **p <= 'Z'
-            || **p == '_' 
-            || **p >= '0' && **p <= '9')
-        {
-            string_push_back2(not_evaled, **p);
-            string_push_back2(arg_name, **p);
-            (*p)++;
-        }
-
-        skip_spaces(p, not_evaled);
-
-        if(**p != ')') {
-            err_msg("require )", sname, *sline);
-
-            return FALSE;
-        }
-
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-    }
-/*
-    /// 引数を取る ///
-    vector_obj* args = VECTOR_NEW(10);
-    string_obj* arg_name = STRING_NEW("");
-    if(**p == '(') {
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-        while(1) {
-            skip_spaces(p, not_evaled);
-
-            string_obj* arg = STRING_NEW("");
-
-            while(**p >= 'a' && **p <= 'z' 
-                || **p >= 'A' && **p <= 'Z'
-                || **p == '_' 
-                || **p >= '0' && **p <= '9')
-            {
-                string_push_back2(not_evaled, **p);
-                string_push_back2(arg, **p);
-                (*p)++;
-            }
-
-            skip_spaces(p, not_evaled);
-
-            if(string_length(arg) > 0) {
-                vector_add(args, arg);
-            }
-
-            if(**p == ')') {
-                break;
-            }
-            else if(**p >= 'a' && **p <= 'z' 
-                || **p >= 'A' && **p <= 'Z'
-                || **p == '_' 
-                || **p >= '0' && **p <= '9')
-            {
-            }
-            else {
-                err_msg("invalid character in argument", sname, *sline);
-                return FALSE;
-            }
-        }
-
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-    }
-*/
-
-    while(**p) {
-        if(**p == '\n') {
-            (*sline)++;
-            string_push_back2(not_evaled, **p);
-            (*p)++;
-        }
-        else if(**p == ' ' || **p == '\t') {
-            string_push_back2(not_evaled, **p);
-            (*p)++;
-        }
-        else {
-            break;
-        }
-    }
-
-    string_obj* contents = STRING_NEW("");
-    if(**p == '{') {
-        if(!read_block(p, contents, NULL, not_evaled, FALSE, sname, sline)) {
-            return FALSE;
-        }
-    }
-    else {
-        err_msg("unexpected token at def statment", sname, *sline);
-        return FALSE;
-    }
-
-    sStatments* statments = STATMENTS_NEW();
-
-    if(!parse(string_c_str(contents), sname, sline, statments)) 
-    {
-
-        return FALSE;
-    }
-
-
-    command->mKind = kDef;
-        // これが無いとmNotEvaledの場合（変数がある場合）
-        // 正しくcommandが消されない
-    command->mExtra = sFunction_new(string_c_str(name), statments, string_c_str(arg_name), NULL);
-
-
-    return TRUE;
-}
-
-/// class文読み込み
-static BOOL read_command_parse_class_statment(char** p, sCommand* command, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, char* sname, int* sline)
-{
-    skip_spaces(p, not_evaled);
-
-    /// クラス名を得る ///
-    string_obj* name = STRING_NEW("");
-    while(**p >= 'a' && **p <= 'z' 
-            || **p >= 'A' && **p <= 'Z'
-            || **p == '_' 
-            || **p >= '0' && **p <= '9')
-    {
-        string_push_back2(not_evaled, **p);
-        string_push_back2(name, **p);
-        (*p)++;
-    }
-
-    while(**p) {
-        if(**p == '\n') {
-            (*sline)++;
-            string_push_back2(not_evaled, **p);
-            (*p)++;
-        }
-        else if(**p == ' ' || **p == '\t') {
-            string_push_back2(not_evaled, **p);
-            (*p)++;
-        }
-        else {
-            break;
-        }
-    }
-
-    string_obj* contents = STRING_NEW("");
-    if(**p == '{') {
-        if(!read_block(p, contents, NULL, not_evaled, FALSE, sname, sline)) {
-            return FALSE;
-        }
-    }
-    else {
-        err_msg("unexpected token at def statment", sname, *sline);
-        return FALSE;
-    }
-
-    sStatments* statments = STATMENTS_NEW();
-
-    if(!parse(string_c_str(contents), sname, sline, statments)) 
-    {
-
-        return FALSE;
-    }
-
-    command->mKind = kClass;
-        // これが無いとmNotEvaledの場合（変数がある場合）
-        // 正しくcommandが消されない
-    command->mExtra = sClass_new(string_c_str(name), statments, NULL);
-
-    return TRUE;
-}
-
 /// １コマンド読み込み
 static BOOL read_command(char** p, sCommand* command, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, BOOL block_termination, char* sname, int* sline)
 {
@@ -1134,26 +937,6 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
                         return FALSE;
                     }
                 }
-                else if(strcmp(string_c_str(buf), "def") == 0) {
-                    vector_add(command->mArgs, sArg_new(0, buf));
-                    string_push_back(statment->mTitle, string_c_str(buf));
-                    string_push_back(statment->mTitle, " ");
-
-                    if(!read_command_parse_def_statment(p, command, statment, not_evaled, read_end_of_statment, sname, sline))
-                    {
-                        return FALSE;
-                    }
-                }
-                else if(strcmp(string_c_str(buf), "class") == 0) {
-                    vector_add(command->mArgs, sArg_new(0, buf));
-                    string_push_back(statment->mTitle, string_c_str(buf));
-                    string_push_back(statment->mTitle, " ");
-
-                    if(!read_command_parse_class_statment(p, command, statment, not_evaled, read_end_of_statment, sname, sline))
-                    {
-                        return FALSE;
-                    }
-                }
                 else {
                     if(vector_size(statment->mCommands) == 0 && strcmp(string_c_str(buf), "!") == 0)
                     {
@@ -1736,6 +1519,8 @@ BOOL parse(char* cmdline, char* sname, int* sline, sStatments* statments)
 {
     char* p = cmdline;
 
+    string_put(statments->mSource, cmdline);
+
     while(*p) {
         /// 行前のスペースを削除 ///
         while(*p == ' ' || *p == '\t' || *p == '\n' && (*sline)++) { p++; }
