@@ -750,6 +750,8 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             return TRUE;
         }
 
+        const BOOL input = !first_program || exist_globalin || exist_stdinpipe;
+
         int ii;
 
         char* arg0 = string_c_str(vector_item(argv, 0));
@@ -835,6 +837,8 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
         /// クラス ///
         if(klass) {
+            klass->input = input;
+
             if(vector_size(argv) >= 2) {
                 char* objname = string_c_str(vector_item(argv, 1));
 
@@ -848,7 +852,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                 vector_add(gStackFrameHashs, HASH_NEW(30));
                 vector_add(gStackFrameArrays, HASH_NEW(30));
 
-                sObject* object2 = sObject_new(objname, object);
+                sObject* object2 = sObject_new(objname, klass, object);
                 if(object) {
                     hash_put(object->mObjects, objname, object2);
                 }
@@ -935,6 +939,8 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                     err_msg("class name is not found", sname, sline);
                     return FALSE;
                 }
+
+                klass->input = input;
                 
                 *rcode = run(klass->statments, title, nextout
                                 , nextin, nexterr
@@ -1031,6 +1037,8 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         }
         /// メソッド ///
         else if(method) {
+            method->input = input;
+
             if(!statment_tree_redirect(command, &nextin, &nextout
                             , &nexterr, pipein, pipeout, pipeerr, sname, sline))
             {
@@ -1149,6 +1157,8 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
         /// ユーザーコマンド ///
         else if(fun) {
+            fun->input = input;
+
             if(!statment_tree_redirect(command, &nextin, &nextout
                             , &nexterr, pipein, pipeout, pipeerr, sname, sline))
             {
@@ -1286,7 +1296,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             BOOL r = inner_fun->mFun(rcode, argv, blocks, parent_blocks
                         , nextout, nextin, nexterr
-                        , title, !first_program || exist_globalin || exist_stdinpipe);
+                        , title, input);
 
             /// 終了コード ///
             if(statment->mRCodeReverse) {
@@ -1326,7 +1336,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             }
 
             BOOL r = statment_tree_internal_commands(command, rcode
-                , argv, blocks, parent_blocks, nextout, nextin, nexterr, j, title, !first_program || exist_globalin || exist_stdinpipe, return_, enable_return, break_, enable_break, sname, sline, envs, object, running_fun, running_class);
+                , argv, blocks, parent_blocks, nextout, nextin, nexterr, j, title, input, return_, enable_return, break_, enable_break, sname, sline, envs, object, running_fun, running_class);
 
             /// 終了コード ///
             if(statment->mRCodeReverse) {
